@@ -10,6 +10,8 @@ REGION = "us-west-1"
 SNAPSHOT_GQL_API_URL = "https://hub.snapshot.org/graphql"
 SNAPSHOT_SCORES_URL = "https://score.snapshot.org/api/scores"
 SNAPSHOT_VOTE_API = "https://hub.snapshot.org/api/msg"
+COWSWAP_TRADES_URL = "https://api.cow.fi/mainnet/api/v1/trades/"
+BINANCE_KLINES_URL = "https://api.binance.com/api/v3/klines"
 
 # EOA
 BADGER_VOTER_ADDRESS = "0x14F83fF95D4Ec5E8812DDf42DA1232b0ba1015e6"
