@@ -5,7 +5,7 @@ from discord import RequestsWebhookAdapter
 from discord import Webhook
 
 from badger_voter_sdk.aws import get_secret
-from badger_voter_sdk.rich_logger import logger
+from badger_voter_sdk.json_logger import logger
 
 
 def send_code_block_to_discord(
